@@ -3,15 +3,15 @@ from rich import print
 from cognite_toolkit._cdf_tk.client import ToolkitClient
 from cognite_toolkit._cdf_tk.commands._base import ToolkitCommand
 from cognite_toolkit._cdf_tk.commands.deploy import DeployCommand
-from cognite_toolkit._cdf_tk.data_classes import DeployResults
-from cognite_toolkit._cdf_tk.loaders import (
-    ContainerLoader,
-    DataModelLoader,
+from cognite_toolkit._cdf_tk.cruds import (
+    ContainerCRUD,
+    DataModelCRUD,
+    ResourceViewMappingCRUD,
     ResourceWorker,
-    SpaceLoader,
-    ViewLoader,
-    ViewSourceLoader,
+    SpaceCRUD,
+    ViewCRUD,
 )
+from cognite_toolkit._cdf_tk.data_classes import DeployResults
 
 from .data_model import COGNITE_MIGRATION_MODEL, CONTAINERS, MODEL_ID, SPACE, VIEWS
 from .default_mappings import create_default_mappings
@@ -28,17 +28,17 @@ class MigrationPrepareCommand(ToolkitCommand):
         print(f"{verb} {MODEL_ID!r}")
         results = DeployResults([], "deploy", dry_run=dry_run)
         for loader_cls, resource_list in [
-            (SpaceLoader, [SPACE]),
-            (ContainerLoader, CONTAINERS),
-            (ViewLoader, VIEWS),
-            (DataModelLoader, [COGNITE_MIGRATION_MODEL]),
-            (ViewSourceLoader, create_default_mappings()),
+            (SpaceCRUD, [SPACE]),
+            (ContainerCRUD, CONTAINERS),
+            (ViewCRUD, VIEWS),
+            (DataModelCRUD, [COGNITE_MIGRATION_MODEL]),
+            (ResourceViewMappingCRUD, create_default_mappings()),
         ]:
             # MyPy does not understand that `loader_cls` has a `create_loader` method.
             loader = loader_cls.create_loader(client)  # type: ignore[attr-defined]
             worker = ResourceWorker(loader, "deploy")
             # MyPy does not understand that `loader` has a `get_id` method.
-            dump_arg = {"context": "local"} if loader_cls is ViewSourceLoader else {}
+            dump_arg = {"context": "local"} if loader_cls is ResourceViewMappingCRUD else {}
             local_by_id = {loader.get_id(item): (item.dump(**dump_arg), item) for item in resource_list}  # type: ignore[attr-defined]
             worker.validate_access(local_by_id, is_dry_run=dry_run)
             cdf_resources = loader.retrieve(list(local_by_id.keys()))
