@@ -1,11 +1,13 @@
+import dataclasses
 import uuid
-from collections.abc import Callable, Hashable
+from collections.abc import Callable, Hashable, Iterable, Sequence
 from functools import partial
 from graphlib import CycleError, TopologicalSorter
 from typing import cast
 
 import questionary
 from cognite.client.data_classes import AggregateResultItem, DataSetUpdate, filters
+from cognite.client.data_classes._base import CogniteResourceList
 from cognite.client.data_classes.data_modeling import NodeId, ViewId
 from cognite.client.exceptions import CogniteAPIError
 from cognite.client.utils._identifier import InstanceId
@@ -15,6 +17,28 @@ from rich.panel import Panel
 from rich.status import Status
 
 from cognite_toolkit._cdf_tk.client import ToolkitClient
+from cognite_toolkit._cdf_tk.cruds import (
+    RESOURCE_CRUD_LIST,
+    AssetCRUD,
+    CogniteFileCRUD,
+    ContainerCRUD,
+    DataModelCRUD,
+    DataSetsCRUD,
+    EdgeCRUD,
+    FunctionCRUD,
+    GraphQLCRUD,
+    GroupAllScopedCRUD,
+    GroupCRUD,
+    GroupResourceScopedCRUD,
+    HostedExtractorDestinationCRUD,
+    LocationFilterCRUD,
+    NodeCRUD,
+    ResourceCRUD,
+    SpaceCRUD,
+    StreamlitCRUD,
+    TransformationCRUD,
+    ViewCRUD,
+)
 from cognite_toolkit._cdf_tk.data_classes import DeployResults, ResourceDeployResult
 from cognite_toolkit._cdf_tk.exceptions import (
     AuthorizationError,
@@ -23,25 +47,6 @@ from cognite_toolkit._cdf_tk.exceptions import (
     ToolkitRequiredValueError,
     ToolkitValueError,
 )
-from cognite_toolkit._cdf_tk.loaders import (
-    RESOURCE_LOADER_LIST,
-    AssetLoader,
-    CogniteFileLoader,
-    DataSetsLoader,
-    FunctionLoader,
-    GraphQLLoader,
-    GroupAllScopedLoader,
-    GroupLoader,
-    GroupResourceScopedLoader,
-    HostedExtractorDestinationLoader,
-    LocationFilterLoader,
-    NodeLoader,
-    ResourceLoader,
-    SpaceLoader,
-    StreamlitLoader,
-    TransformationLoader,
-    ViewLoader,
-)
 from cognite_toolkit._cdf_tk.storageio import InstanceIO, InstanceSelector
 from cognite_toolkit._cdf_tk.tk_warnings import (
     HighSeverityWarning,
@@ -49,7 +54,13 @@ from cognite_toolkit._cdf_tk.tk_warnings import (
     MediumSeverityWarning,
 )
 from cognite_toolkit._cdf_tk.utils import humanize_collection
-from cognite_toolkit._cdf_tk.utils.batch_processor import BatchResult, HTTPBatchProcessor
+from cognite_toolkit._cdf_tk.utils.http_client import (
+    FailedRequestMessage,
+    HTTPClient,
+    ItemsRequest,
+    ResponseMessage,
+    SuccessItem,
+)
 from cognite_toolkit._cdf_tk.utils.producer_worker import ProducerWorkerExecutor
 from cognite_toolkit._cdf_tk.utils.useful_types import JsonVal
 from cognite_toolkit._cdf_tk.utils.validate_access import ValidateAccess
@@ -57,7 +68,15 @@ from cognite_toolkit._cdf_tk.utils.validate_access import ValidateAccess
 from ._base import ToolkitCommand
 
 
+@dataclasses.dataclass
+class DeleteResults:
+    deleted: int = 0
+    failed: int = 0
+
+
 class PurgeCommand(ToolkitCommand):
+    BATCH_SIZE_DM = 1000
+
     def space(
         self,
         client: ToolkitClient,
@@ -81,20 +100,27 @@ class PurgeCommand(ToolkitCommand):
                 ).ask()
                 if not confirm:
                     return
-
+                confirm = questionary.confirm(
+                    f"If any of the nodes in {selected_space!r} are TimeSeries or Files, this will delete the "
+                    "datapoints and file contents. If you want to unlink the nodes before deleting, please use the "
+                    "cdf purge instances command. Are you sure you want to continue?",
+                    default=False,
+                ).ask()
+                if not confirm:
+                    return
         loaders = self._get_dependencies(
-            SpaceLoader,
+            SpaceCRUD,
             exclude={
-                GraphQLLoader,
-                GroupResourceScopedLoader,
-                LocationFilterLoader,
-                TransformationLoader,
-                CogniteFileLoader,
+                GraphQLCRUD,
+                GroupResourceScopedCRUD,
+                LocationFilterCRUD,
+                TransformationCRUD,
+                CogniteFileCRUD,
             },
         )
         is_purged = self._purge(client, loaders, selected_space, dry_run=dry_run, verbose=verbose)
         if include_space and is_purged:
-            space_loader = SpaceLoader.create_loader(client)
+            space_loader = SpaceCRUD.create_loader(client)
             if dry_run:
                 print(f"Would delete space {selected_space}")
             else:
@@ -111,13 +137,133 @@ class PurgeCommand(ToolkitCommand):
         elif not dry_run:
             print(f"Purge space {selected_space!r} partly completed. See warnings for details.")
 
+    def space_v2(
+        self,
+        client: ToolkitClient,
+        selected_space: str,
+        include_space: bool = False,
+        dry_run: bool = False,
+        auto_yes: bool = False,
+        verbose: bool = False,
+    ) -> DeployResults:
+        results = DeployResults([], "purge", dry_run=dry_run)
+
+        # Warning Messages
+        if not dry_run:
+            self._print_panel("space", selected_space)
+        if not dry_run and not auto_yes:
+            confirm = questionary.confirm(
+                f"Are you really sure you want to purge the {selected_space!r} space?", default=False
+            ).ask()
+            if not confirm:
+                return results
+
+        stats = client.data_modeling.statistics.spaces.retrieve(selected_space)
+        if stats is None:
+            raise ToolkitMissingResourceError(f"Space {selected_space!r} does not exist")
+
+        # ValidateAuth
+        validator = ValidateAccess(client, "purge")
+        if include_space or (stats.containers + stats.views + stats.data_models) > 0:
+            validator.data_model(["read", "write"], spaces={selected_space})
+        if (stats.nodes + stats.edges) > 0:
+            validator.instances(["read", "write"], spaces={selected_space})
+
+        config = client.config
+        total_by_crud_cls = {
+            EdgeCRUD: (stats.edges, config.create_api_url("/models/instances/delete")),
+            NodeCRUD: (stats.nodes, config.create_api_url("/models/instances/delete")),
+            DataModelCRUD: (stats.data_models, config.create_api_url("/models/datamodels/delete")),
+            ViewCRUD: (stats.views, config.create_api_url("/models/views/delete")),
+            ContainerCRUD: (stats.containers, config.create_api_url("/models/containers/delete")),
+        }
+        if dry_run:
+            for crud_cls, (total, _) in total_by_crud_cls.items():
+                crud = crud_cls.create_loader(client)  # type: ignore[attr-defined]
+                results[crud.display_name] = ResourceDeployResult(crud.display_name, deleted=total)
+            if include_space:
+                space_loader = SpaceCRUD.create_loader(client)
+                results[space_loader.display_name] = ResourceDeployResult(space_loader.display_name, deleted=1)
+        else:
+            with HTTPClient(client.config, max_retries=10) as delete_client:
+                for crud_cls, (total, URL) in total_by_crud_cls.items():
+                    crud = crud_cls.create_loader(client)  # type: ignore[attr-defined]
+                    if total == 0:
+                        results[crud.display_name] = ResourceDeployResult(crud.display_name, deleted=0)
+                        continue
+                    result = ResourceDeployResult(crud.display_name)
+                    # Containers, DataModels and Views need special handling to avoid type info in the delete call
+                    # While for instance we need the type info in delete.
+                    dump_args = (
+                        {"include_type": False} if isinstance(crud, ContainerCRUD | DataModelCRUD | ViewCRUD) else {}
+                    )
+                    executor = ProducerWorkerExecutor[CogniteResourceList, list[JsonVal]](
+                        download_iterable=self._iterate_batch(crud, selected_space, batch_size=self.BATCH_SIZE_DM),
+                        process=lambda list_: [item.as_id().dump(**dump_args) for item in list_],
+                        write=self._purge_batch(crud, URL, delete_client, result),
+                        max_queue_size=10,
+                        iteration_count=total // self.BATCH_SIZE_DM + (1 if total % self.BATCH_SIZE_DM > 0 else 0),
+                        download_description=f"Downloading {crud.display_name}",
+                        process_description=f"Preparing {crud.display_name} for deletion",
+                        write_description=f"Deleting {crud.display_name}",
+                    )
+                    executor.run()
+                    results[crud.display_name] = result
+                    if executor.error_occurred:
+                        self.warn(
+                            HighSeverityWarning(f"Failed to delete all {crud.display_name}. {executor.error_message}")
+                        )
+            if include_space:
+                space_loader = SpaceCRUD.create_loader(client)
+                try:
+                    space_loader.delete([selected_space])
+                    print(f"Space {selected_space} deleted")
+                except CogniteAPIError as e:
+                    self.warn(HighSeverityWarning(f"Failed to delete space {selected_space!r}: {e}"))
+                else:
+                    results[space_loader.display_name] = ResourceDeployResult(space_loader.display_name, deleted=1)
+        print(results.counts_table(exclude_columns={"Created", "Changed", "Total"}))
+        return results
+
+    @staticmethod
+    def _iterate_batch(crud: ResourceCRUD, selected_space: str, batch_size: int) -> Iterable[CogniteResourceList]:
+        batch = crud.list_cls([])
+        for resource in crud.iterate(space=selected_space):
+            batch.append(resource)
+            if len(batch) >= batch_size:
+                yield batch
+                batch = crud.list_cls([])
+        if batch:
+            yield batch
+
+    @staticmethod
+    def _purge_batch(
+        crud: ResourceCRUD, delete_url: str, delete_client: HTTPClient, result: ResourceDeployResult
+    ) -> Callable[[list[JsonVal]], None]:
+        def process(items: list[JsonVal]) -> None:
+            responses = delete_client.request_with_retries(
+                ItemsRequest(
+                    endpoint_url=delete_url,
+                    method="POST",
+                    items=items,
+                    as_id=crud.get_id,
+                )
+            )
+            for response in responses:
+                if isinstance(response, SuccessItem):
+                    result.deleted += 1
+                else:
+                    result.unchanged += 1
+
+        return process
+
     @staticmethod
     def _get_dependencies(
-        loader_cls: type[ResourceLoader], exclude: set[type[ResourceLoader]] | None = None
-    ) -> dict[type[ResourceLoader], frozenset[type[ResourceLoader]]]:
+        loader_cls: type[ResourceCRUD], exclude: set[type[ResourceCRUD]] | None = None
+    ) -> dict[type[ResourceCRUD], frozenset[type[ResourceCRUD]]]:
         return {
             dep_cls: dep_cls.dependencies
-            for dep_cls in RESOURCE_LOADER_LIST
+            for dep_cls in RESOURCE_CRUD_LIST
             if loader_cls in dep_cls.dependencies and (exclude is None or dep_cls not in exclude)
         }
 
@@ -167,15 +313,15 @@ class PurgeCommand(ToolkitCommand):
                     return
 
         loaders = self._get_dependencies(
-            DataSetsLoader,
+            DataSetsCRUD,
             exclude={
-                GroupLoader,
-                GroupResourceScopedLoader,
-                GroupAllScopedLoader,
-                StreamlitLoader,
-                HostedExtractorDestinationLoader,
-                FunctionLoader,
-                LocationFilterLoader,
+                GroupCRUD,
+                GroupResourceScopedCRUD,
+                GroupAllScopedCRUD,
+                StreamlitCRUD,
+                HostedExtractorDestinationCRUD,
+                FunctionCRUD,
+                LocationFilterCRUD,
             },
         )
         is_purged = self._purge(client, loaders, selected_data_set=selected_dataset, dry_run=dry_run, verbose=verbose)
@@ -235,7 +381,7 @@ class PurgeCommand(ToolkitCommand):
     def _purge(
         self,
         client: ToolkitClient,
-        loaders: dict[type[ResourceLoader], frozenset[type[ResourceLoader]]],
+        loaders: dict[type[ResourceCRUD], frozenset[type[ResourceCRUD]]],
         selected_space: str | None = None,
         selected_data_set: str | None = None,
         dry_run: bool = False,
@@ -244,7 +390,7 @@ class PurgeCommand(ToolkitCommand):
     ) -> bool:
         is_purged = True
         results = DeployResults([], "purge", dry_run=dry_run)
-        loader_cls: type[ResourceLoader]
+        loader_cls: type[ResourceCRUD]
         has_purged_views = False
         with Console().status("...", spinner="aesthetic", speed=0.4) as status:
             for loader_cls in reversed(list(TopologicalSorter(loaders).static_order())):
@@ -253,11 +399,11 @@ class PurgeCommand(ToolkitCommand):
                     continue
                 loader = loader_cls.create_loader(client, console=status.console)
                 status_prefix = "Would have deleted" if dry_run else "Deleted"
-                if isinstance(loader, ViewLoader) and not dry_run:
+                if isinstance(loader, ViewCRUD) and not dry_run:
                     status_prefix = "Expected deleted"  # Views are not always deleted immediately
                     has_purged_views = True
 
-                if not dry_run and isinstance(loader, NodeLoader):
+                if not dry_run and isinstance(loader, NodeCRUD):
                     # Special handling of nodes as node type must be deleted after regular nodes
                     # In dry-run mode, we are not deleting the nodes, so we can skip this.
                     warnings_before = len(self.warning_list)
@@ -272,7 +418,7 @@ class PurgeCommand(ToolkitCommand):
                     ):
                         is_purged = False
                     continue
-                elif not dry_run and isinstance(loader, AssetLoader):
+                elif not dry_run and isinstance(loader, AssetCRUD):
                     # Special handling of assets as we must ensure all children are deleted before the parent.
                     # In dry-run mode, we are not deleting the assets, so we can skip this.
                     deleted_assets = self._purge_assets(loader, status, selected_data_set)
@@ -349,7 +495,7 @@ class PurgeCommand(ToolkitCommand):
         self,
         batch_ids: list[Hashable],
         dry_run: bool,
-        loader: ResourceLoader,
+        loader: ResourceCRUD,
         batch_size: int,
         console: Console,
         verbose: bool,
@@ -393,7 +539,7 @@ class PurgeCommand(ToolkitCommand):
 
     @staticmethod
     def _delete_children(
-        parent_ids: list[Hashable], child_loaders: list[ResourceLoader], dry_run: bool, console: Console, verbose: bool
+        parent_ids: list[Hashable], child_loaders: list[ResourceCRUD], dry_run: bool, console: Console, verbose: bool
     ) -> dict[str, int]:
         child_deletion: dict[str, int] = {}
         for child_loader in child_loaders:
@@ -415,7 +561,7 @@ class PurgeCommand(ToolkitCommand):
 
     def _purge_nodes(
         self,
-        loader: NodeLoader,
+        loader: NodeCRUD,
         status: Status,
         selected_space: str | None = None,
         verbose: bool = False,
@@ -473,7 +619,7 @@ class PurgeCommand(ToolkitCommand):
         return count
 
     def _delete_node_batch(
-        self, batch_ids: list[NodeId], loader: NodeLoader, batch_size: int, console: Console, verbose: bool
+        self, batch_ids: list[NodeId], loader: NodeCRUD, batch_size: int, console: Console, verbose: bool
     ) -> tuple[int, int]:
         try:
             deleted = loader.delete(batch_ids)
@@ -531,7 +677,7 @@ class PurgeCommand(ToolkitCommand):
 
     def _purge_assets(
         self,
-        loader: AssetLoader,
+        loader: AssetCRUD,
         status: Status,
         selected_data_set: str | None = None,
         batch_size: int = 1000,
@@ -603,7 +749,7 @@ class PurgeCommand(ToolkitCommand):
         auto_yes: bool = False,
         unlink: bool = True,
         verbose: bool = False,
-    ) -> None:
+    ) -> DeleteResults:
         """Purge instances"""
         io = InstanceIO(client)
         console = Console()
@@ -616,7 +762,7 @@ class PurgeCommand(ToolkitCommand):
         total = io.count(selector)
         if total is None or total == 0:
             print("No instances found.")
-            return
+            return DeleteResults()
         if not dry_run:
             self._print_panel("instances", str(selector))
             if not auto_yes:
@@ -625,27 +771,21 @@ class PurgeCommand(ToolkitCommand):
                     default=False,
                 ).ask()
                 if not confirm:
-                    return
+                    return DeleteResults()
 
         process: Callable[[list[InstanceId]], list[dict[str, JsonVal]]] = self._prepare
         if unlink:
             process = partial(self._unlink_prepare, client=client, dry_run=dry_run, console=console, verbose=verbose)
 
-        iteration_count = int(total // io.chunk_size + (1 if total % io.chunk_size > 0 else 0))
-        with HTTPBatchProcessor(
-            endpoint_url=client.config.create_api_url("/models/instances/delete"),
-            config=client.config,
-            as_id=InstanceId.load,  # type: ignore[arg-type]
-            result_processor=self._no_op_results,
-            batch_size=io.chunk_size,
-            max_workers=1,
-        ) as http_client:
+        iteration_count = int(total // io.CHUNK_SIZE + (1 if total % io.CHUNK_SIZE > 0 else 0))
+        with HTTPClient(config=client.config) as delete_client:
             process_str = "Would be unlinking" if dry_run else "Unlinking"
             write_str = "Would be deleting" if dry_run else "Deleting"
+            results = DeleteResults()
             executor = ProducerWorkerExecutor[list[InstanceId], list[dict[str, JsonVal]]](
                 download_iterable=io.download_ids(selector),
                 process=process,
-                write=self._no_delete if dry_run else http_client.add_items,
+                write=partial(self._delete_instance_ids, dry_run=dry_run, delete_client=delete_client, results=results),
                 iteration_count=iteration_count,
                 max_queue_size=10,
                 download_description=f"Retrieving instances from {selector!s}",
@@ -658,7 +798,13 @@ class PurgeCommand(ToolkitCommand):
             executor.raise_on_error()
 
         prefix = "Would have purged" if dry_run else "Purged"
-        console.print(f"{prefix} {executor.total_items:,} instances in {selector!s}")
+        if results.failed == 0:
+            console.print(f"{prefix} {results.deleted:,} instances in {selector!s}")
+        else:
+            console.print(
+                f"{prefix} {results.deleted:,} instances in {selector!s}, but failed to purge {results.failed:,} instances"
+            )
+        return results
 
     def validate_instance_access(self, validator: ValidateAccess, instance_spaces: list[str] | None) -> None:
         space_ids = validator.instances(
@@ -736,16 +882,28 @@ class PurgeCommand(ToolkitCommand):
         return self._prepare(instance_ids)
 
     @staticmethod
-    def _no_delete(instances: list[dict[str, JsonVal]]) -> None:
-        """No operation function that does not delete the instances."""
-        # This is used in dry-run mode to avoid actual deletion
-        pass
+    def _delete_instance_ids(
+        items: list[dict[str, JsonVal]], dry_run: bool, delete_client: HTTPClient, results: DeleteResults
+    ) -> None:
+        if dry_run:
+            results.deleted += len(items)
+            return
 
-    @staticmethod
-    def _no_op_results(results: BatchResult[InstanceId]) -> None:
-        """No operation function that does not process results."""
-        # This is used in dry-run mode to avoid actual processing
-        pass
+        responses: Sequence[ResponseMessage | FailedRequestMessage] = delete_client.request_with_retries(
+            ItemsRequest(
+                delete_client.config.create_api_url("/models/instances/delete"),
+                method="POST",
+                # MyPy fails to understand that dict[str, JsonVal] is compatible with JsonVal
+                items=items,  # type: ignore[arg-type]
+                # The PySDK does not use the JsonVal type hint, but we know these are correct
+                as_id=InstanceId.load,  # type: ignore[arg-type]
+            )
+        )
+        for response in responses:
+            if isinstance(response, SuccessItem):
+                results.deleted += 1
+            else:
+                results.failed += 1
 
     @staticmethod
     def _unlink_timeseries(
