@@ -21,12 +21,18 @@ from .function_schedule import FunctionScheduleYAML
 from .functions import FunctionsYAML
 from .groups import GroupYAML
 from .hosted_extractor_destination import HostedExtractorDestinationYAML
+from .hosted_extractor_job import HostedExtractorJobYAML
 from .hosted_extractor_mapping import HostedExtractorMappingYAML
+from .hosted_extractor_source import HostedExtractorSourceYAML
+from .instance import EdgeYAML, NodeYAML
 from .labels import LabelsYAML
 from .location import LocationYAML
 from .raw_database_table import DatabaseYAML, TableYAML
+from .relationship import RelationshipYAML
+from .robotics import RobotCapabilityYAML, RobotDataPostProcessingYAML, RobotFrameYAML, RobotLocationYAML, RobotMapYAML
 from .search_config import SearchConfigYAML
 from .securitycategories import SecurityCategoriesYAML
+from .sequence import SequenceYAML
 from .space import SpaceYAML
 from .streamlit_ import StreamlitYAML
 from .threedmodels import ThreeDModelYAML
@@ -44,9 +50,11 @@ __all__ = [
     "BaseModelResource",
     "ContainerYAML",
     "DataModelYAML",
+    "DataModelYAML",
     "DataSetYAML",
     "DatabaseYAML",
     "DatapointSubscriptionYAML",
+    "EdgeYAML",
     "EventYAML",
     "ExtractionPipelineConfigYAML",
     "ExtractionPipelineYAML",
@@ -55,11 +63,21 @@ __all__ = [
     "FunctionsYAML",
     "GroupYAML",
     "HostedExtractorDestinationYAML",
+    "HostedExtractorJobYAML",
     "HostedExtractorMappingYAML",
+    "HostedExtractorSourceYAML",
     "LabelsYAML",
     "LocationYAML",
+    "NodeYAML",
+    "RelationshipYAML",
+    "RobotCapabilityYAML",
+    "RobotDataPostProcessingYAML",
+    "RobotFrameYAML",
+    "RobotLocationYAML",
+    "RobotMapYAML",
     "SearchConfigYAML",
     "SecurityCategoriesYAML",
+    "SequenceYAML",
     "SpaceYAML",
     "StreamlitYAML",
     "TableYAML",
