@@ -13,6 +13,7 @@ from ._selectors import (
     ChartOwnerSelector,
     ChartSelector,
     DataSetSelector,
+    InstanceFileSelector,
     InstanceSelector,
     InstanceViewSelector,
 )
@@ -30,6 +31,7 @@ __all__ = [
     "ChartSelector",
     "DataSetSelector",
     "FileMetadataIO",
+    "InstanceFileSelector",
     "InstanceIO",
     "InstanceIdCSVList",
     "InstanceIdRow",
