@@ -65,7 +65,7 @@ from cognite_toolkit._cdf_tk.client.data_classes.graphql_data_models import Grap
 from cognite_toolkit._cdf_tk.client.data_classes.raw import RawDatabase
 from cognite_toolkit._cdf_tk.client.testing import ToolkitClientMock
 from cognite_toolkit._cdf_tk.constants import INDEX_PATTERN
-from cognite_toolkit._cdf_tk.loaders import FileLoader
+from cognite_toolkit._cdf_tk.cruds import FileCRUD
 from cognite_toolkit._cdf_tk.utils import calculate_hash
 from cognite_toolkit._cdf_tk.utils.auth import CLIENT_NAME
 
@@ -682,7 +682,7 @@ class ApprovalToolkitClient:
                 entry = instance_id.dump(include_instance_type=False)
             entry["filehash"] = filehash
 
-            created_resources[FileLoader.__name__].append(entry)
+            created_resources[FileCRUD.__name__].append(entry)
 
             return FileMetadata(external_id, instance_id)
 
@@ -994,6 +994,8 @@ class ApprovalToolkitClient:
                             return v["dbName"] + "/" + v["name"][0]
                         if "transformationExternalId" in v and "destination" in v:
                             return v["transformationExternalId"] + v["destination"]
+                        if "view" in v and "space" in v["view"] and "externalId" in v["view"]:
+                            return v["view"]["space"] + "/" + v["view"]["externalId"]
                         raise ValueError(f"Could not find identifier in {v}")
 
                     dumped[key] = sorted(dumped_resource, key=sort_key)
